@@ -1,4 +1,4 @@
-﻿import monitor
+import monitor
 import daemon
 import psutil
 import lib
\ No newline at end of file
